"use server";

import { MoveFormData } from "@/schemas";
import { CustomItem } from "@/store";
import { FormResponse } from "@/types";

let moveUrl = "https://artur-system.clouderp.ke/api/resource/";

export async function handleMoveRequestAction(
  data: MoveFormData,
  wohnzimmer: CustomItem,
  arbeitszimmer: CustomItem,
  kinderzimmer: CustomItem,
  diele: CustomItem,
  esszimmer: CustomItem,
  schlafzimmer: CustomItem,
  kuche: CustomItem,
  keller: CustomItem,
  garage: CustomItem
): Promise<FormResponse> {
  let payload = getPayload(
    data,
    wohnzimmer,
    arbeitszimmer,
    kinderzimmer,
    diele,
    esszimmer,
    schlafzimmer,
    kuche,
    keller,
    garage
  );
  try {
    await fetch(moveUrl + "Project", {
      method: "POST",
      headers: {
        "Content-Type": "application/json",
        Authorization: "token 63a8bf976c7fa9f:26a56e9ed914529",
      },
      body: JSON.stringify(payload),
    });

    return {
      status: 200,
      body: {
        message: "Anfrage erfolgreich gesendet",
      },
    };
  } catch (error) {
    console.log(error);
    return {
      status: 400,
      body: {
        message:
          "Die Verschiebungsanforderung ist fehlgeschlagen. Versuchen Sie es später noch einmal.",
      },
    };
  }
}

function getPayload(
  data: MoveFormData,
  wohnzimmer: CustomItem,
  arbeitszimmer: CustomItem,
  kinderzimmer: CustomItem,
  diele: CustomItem,
  esszimmer: CustomItem,
  schlafzimmer: CustomItem,
  kuche: CustomItem,
  keller: CustomItem,
  garage: CustomItem
) {
  const {
    loadingFrom,
    loadingFromZip,
    loadingFromStreet,
    loadingFromHasNarrowStaircase,
    loadingFromDistanceOver20m,
    loadingFromHasInclinedElevator,
    loadingFromHasEstablishmentOfNoParkingZone,
    loadingFromHasElevator,
    loadingTo,
    loadingToZip,
    loadingToStreet,
    loadingToHasNarrowStaircase,
    loadingToDistanceOver20m,
    loadingToHasInclinedElevator,
    loadingToHasEstablishmentOfNoParkingZone,
    loadingToHasElevator,
    contactTelephone,
    contactEmail,
    contactName,
    moveDate,
  } = data;

  let payload = {
    project_name: `${loadingFrom} 
    Zu ${loadingTo} An ${moveDate}`,
    custom_loading_location_name: loadingFrom,
    custom_zip_and_city: loadingFromZip,
    custom_street_number: loadingFromStreet,
    custom_narrow_staircase: isTrue(loadingFromHasNarrowStaircase),
    custom_removal_distance_over_20m: isTrue(loadingFromDistanceOver20m),
    custom_has_inclined_elevator: isTrue(loadingFromHasInclinedElevator),
    custom_establishment_of_no_parking_zone: isTrue(
      loadingFromHasEstablishmentOfNoParkingZone
    ),
    custom_elevator_available: isTrue(loadingFromHasElevator),
    custom_unloading_location_name: loadingTo,
    custom_unloading_location_zip_and_city: loadingToZip,
    custom_unloading_location_street_number: loadingToStreet,
    custom_unloading_narrow_staircase: isTrue(loadingToHasNarrowStaircase),
    custom_unloading_removal_distance_over_20m: isTrue(
      loadingToDistanceOver20m
    ),
    custom_unloading_has_inclined_elevator: isTrue(
      loadingToHasInclinedElevator
    ),
    custom_unloading_has_establishment_of_no_parking_zone_: isTrue(
      loadingToHasEstablishmentOfNoParkingZone
    ),
    custom_unloading_elevator_available: isTrue(loadingToHasElevator),
    custom_customer_telephone: contactTelephone,
    custom_customer_email_address: contactEmail,
    expected_start_date: moveDate,
    custom_customer_name: contactName,
    ...structureData(wohnzimmer),
    ...structureData(arbeitszimmer),
    ...structureData(kinderzimmer),
    ...structureData(diele),
    ...structureData(esszimmer),
    ...structureData(schlafzimmer),
    ...structureData(kuche),
    ...structureData(keller),
    ...structureData(garage),
    custom_wohnzimmer_sonstiges: wohnzimmer.sonstiges,
    custom_arbeitszimmer_sonstiges: arbeitszimmer.sonstiges,
    custom_kinderzimmer_sonstiges: kinderzimmer.sonstiges,
    custom_diele_sonstiges: diele.sonstiges,
    custom_eßzimmer_sonstiges: esszimmer.sonstiges,
    custom_schlafzimmer_sonstiges: schlafzimmer.sonstiges,
    custom_kuche_sonstiges: kuche.sonstiges,
    custom_keller_sonstiges: keller.sonstiges,
    custom_garage_sonstiges: garage.sonstiges,
  };
  return payload;
}

function isTrue(value: string) {
  switch (value) {
    case "1":
      return true;
    default:
      return false;
  }
}

function structureData(data: CustomItem) {
  let fieldsWithValues = data.fields.filter((f) => f.gesRE);

  let structuredData = {};

  fieldsWithValues.forEach((f) => {
    let newObj = { [f.fpKey]: f.gesRE };
    structuredData = { ...structuredData, ...newObj };
  });

  return structuredData;
}
