import BlogDetail from "@/components/blogs/blog-detail";
import CommonHero from "@/components/common/common-hero";
import { CMS_URL } from "@/config";
import { Blog } from "@/types";
import { Metadata } from "next";
import { notFound } from "next/navigation";

interface Props {
  params: {
    slug: string;
  };
}

const BlogDetailPage = async ({ params: { slug } }: Props) => {
  const blog = await getSingleBlog(slug);
  return (
    <>
      <CommonHero title={blog.title.slice(0, 20) + "..."} route="blog" />
      <BlogDetail blog={blog} />
    </>
  );
};

export default BlogDetailPage;

export async function generateMetadata({
  params: { slug },
}: Props): Promise<Metadata> {
  const blog = await getSingleBlog(slug);
  return {
    title: blog.title,
    description: blog.excerpt,
    openGraph: {
      title: blog.title,
      description: blog.excerpt,
      url: `${CMS_URL}/blogs/${slug}`,
      images: [
        {
          url: CMS_URL + "/" + blog.thumbnail,
          width: 800,
          height: 600,
          alt: blog.title,
        },
      ],
    },
  };
}

async function getSingleBlog(slug: string) {
  try {
    const res = await fetch(getUrl(slug) + "/" + slug, {
      cache: "no-cache",
    });
    const data: {
      data: Blog;
    } = await res.json();

    return data.data;
  } catch (error) {
    notFound();
  }
}

function getUrl(slug: string) {
  return (
    CMS_URL +
    "/items" +
    "/blogs" +
    "/" +
    slug +
    "?fields=slug,title,thumbnail,excerpt,date_created,content" +
    "&status=published"
  );
}
