import Footer from "@/components/footer";
import Navbar from "@/components/navbar";
import { CMS_URL, BASE_URL as url } from "@/config";
import { Globals } from "@/types";
import type { Metadata } from "next";
import { Roboto } from "next/font/google";
import NextTopLoader from "nextjs-toploader";
import "./globals.scss";
import { Providers } from "./providers";

const roboto = Roboto({
  weight: ["400", "500", "700"],
  subsets: ["latin"],
});

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <body
        className={roboto.className}
        style={{
          background: "#ffffff",
        }}
      >
        {" "}
        <NextTopLoader color="#80D765" />
        <Providers>
          <Navbar />
          <main>{children}</main>
          <Footer />
        </Providers>
      </body>
    </html>
  );
}

export async function generateMetadata() {
  return getMetadata();
}

async function getMetadata() {
  try {
    const res = await fetch(`${CMS_URL}/items/globals`, {
      cache: "no-cache",
    });

    const data: {
      data: Globals;
    } = await res.json();

    const globals = data.data;

    return {
      metadataBase: new URL(url),
      title: globals.title,
      description: globals.description,
      openGraph: {
        title: globals.title,
        description: globals.description,
        url: url,
      },
      icons: {
        icon: "/artur-and-helden-favicon.png",
      },
      keywords: globals.keywords.split(","),
    };
  } catch (error) {
    return staticMetadata;
  }
}

const staticMetadata: Metadata = {
  metadataBase: new URL(url),
  title: "Artur & Helden - Ihre beste Umzugs- und Logistikfirma in Deutschland",
  description:
    "Artur & Helden bietet den besten Umzugsservice für lokale und internationale Umzüge, einschließlich Transporte und Lagerdienstleistungen. Erleben Sie Ihren Umzug so einfach wie möglich.",
  openGraph: {
    title:
      "Artur & Helden - Ihre beste Umzugs- und Logistikfirma in Deutschland",
    description:
      "Artur & Helden bietet den besten Umzugsservice für lokale und internationale Umzüge, einschließlich Transporte und Lagerdienstleistungen. Erleben Sie Ihren Umzug so einfach wie möglich.",
    url: url,
  },
  icons: {
    icon: "/favicon.png",
  },
  keywords: [
    "Umzug",
    "Transport",
    "Lagerdienstleistungen",
    "Artur & Helden",
    "Deutschland",
    "Umzugsservice",
    "international",
    "lokal",
    "Ein- & Auspacken",
    "Möbelmontage",
    "Küchenmontage",
    "Entrümpelung",
  ],
};
