import CommonHero from "@/components/common/common-hero";
import RequestMoveOnline from "@/components/common/request-move-online";
import Services from "@/components/services";
import ServicesCTA from "@/components/services/cta";
import Testimonials from "@/components/services/testimonials";
import { CMS_URL } from "@/config";
import { ServicesPage as ServicePageType } from "@/types";
import { notFound } from "next/navigation";

let url =
  CMS_URL +
  "/items" +
  "/leistungen_page" +
  "?fields=cta1_title,cta1_description,book_online_title,book_online_text1,book_online_text2,testimonial_title,services.slug,services.thumbnail,services.title,services.content,testimonials.author_image,testimonials.author_name,testimonials.author_position,testimonials.content" +
  "&status=published";

const ServicesPage = async () => {
  const data = await getServicesData();

  return (
    <>
      <CommonHero route="leistungen" title="Leistungen" />
      <Services servicesData={data.services} />
      <ServicesCTA
        title={data.cta1_title}
        description={data.cta1_description}
      />
      <Testimonials
        testimonials={data.testimonials}
        title={data.testimonial_title}
      />
      <RequestMoveOnline
        title={data.book_online_title}
        text1={data.book_online_text1}
        text2={data.book_online_text2}
      />
    </>
  );
};

export default ServicesPage;

async function getServicesData() {
  try {
    const res = await fetch(url, {
      cache: "no-cache",
    });
    const data: {
      data: ServicePageType;
    } = await res.json();

    return data.data;
  } catch (error) {
    notFound();
  }
}
