import { PageLoading } from "@/components/common";
import RequestMoveOnline from "@/components/common/request-move-online";

import HowItWorks from "@/components/home/how-it-works";
import LatestNews from "@/components/home/latest-news";
import OurServices from "@/components/home/our-services";
import Stats from "@/components/home/stats";
import WeAreAtur from "@/components/home/we-are-artur";
import WhatMakesUsUnique from "@/components/home/what-makes-us-unique";
import { CMS_URL } from "@/config";
import { sampleHomepageData } from "@/data/homepage";
import { Homepage } from "@/types";
import dynamic from "next/dynamic";

const HeroSection = dynamic(() => import("../components/home/hero"), {
  ssr: false,
  loading: () => <PageLoading />,
});

export default async function Home() {
  const homeData = await getHomepageData();

  return (
    <>
      <HeroSection />
      <WhatMakesUsUnique
        data={homeData.why_we_are_unique_cards}
        title={homeData.why_we_are_unique_title}
      />
      <WeAreAtur
        images={homeData.we_are_artur_images}
        title={homeData.we_are_artur_title}
        subTitle={homeData.we_are_artur_sub_title}
        description={homeData.we_are_artur_description}
      />
      <HowItWorks
        title={homeData.how_it_works_title}
        cards={homeData.how_it_works_cards}
      />
      <OurServices
        title={homeData.our_services_title}
        services={homeData.services}
      />
      <Stats stats={homeData.stats} />
      <RequestMoveOnline
        title={homeData.book_online_title}
        text1={homeData.book_online_sub_text_1}
        text2={homeData.book_online_sub_text_2}
      />
      <LatestNews
        title={homeData.home_blog_title}
        blogs={homeData.home_blogs}
      />
    </>
  );
}

async function getHomepageData() {
  try {
    const res = await fetch(getUrl(), {
      cache: "no-cache",
    });
    const data: {
      data: Homepage;
    } = await res.json();

    return data.data;
  } catch (error) {
    return sampleHomepageData;
  }
}

function getUrl() {
  return (
    CMS_URL +
    "/items" +
    "/homepage" +
    "?fields=" +
    "*," +
    "why_we_are_unique_title,why_we_are_unique_cards.id,why_we_are_unique_cards.image,why_we_are_unique_cards.title,why_we_are_unique_cards.description,why_we_are_unique_cards.date_created," +
    "we_are_artur_title,we_are_artur_sub_title,we_are_artur_description," +
    "we_are_artur_images.id,we_are_artur_images.directus_files_id," +
    "how_it_works_title,how_it_works_cards.id,how_it_works_cards.image,how_it_works_cards.title,how_it_works_cards.description,how_it_works_cards.link," +
    "our_services_title,services.slug,services.image_icon,services.title,services.excerpt," +
    "stats.id,stats.title,stats.stat,stats.image," +
    "book_online_title,book_online_sub_text_1,book_online_sub_text_2," +
    "home_blog_title,home_blogs.slug,home_blogs.title,home_blogs.excerpt,home_blogs.date_created,home_blogs.thumbnail" +
    "&filter[home_blogs][status][_eq]=published"
  );
}
