import { BASE_URL as BaseUrl, CMS_URL } from "@/config";

export default async function sitemap() {
  const date = new Date().toISOString();

  const sitemaps = await getSlugs();

  return [
    {
      url: `${BaseUrl}/`,
      lastModified: date,
      changefreq: "daily",
      priority: 1.0,
    },
    {
      url: `${BaseUrl}/kontakt`,
      lastModified: date,
      changefreq: "daily",
      priority: 0.4,
    },
    {
      url: `${BaseUrl}/leistungen`,
      lastModified: date,
      changefreq: "daily",
      priority: 0.6,
    },
    {
      url: `${BaseUrl}/umzugsgutliste`,
      lastModified: date,
      changefreq: "daily",
      priority: 0.6,
    },
    {
      url: `${BaseUrl}/uber-uns`,
      lastModified: date,
      changefreq: "daily",
      priority: 0.6,
    },
    {
      url: `${BaseUrl}/impressum`,
      lastModified: date,
      changefreq: "daily",
      priority: 0.9,
    },
    {
      url: `${BaseUrl}/blogs`,
      lastModified: date,
      changefreq: "daily",
      priority: 0.7,
    },
    ...sitemaps,
  ];
}

const getSlugs = async () => {
  try {
    const res = await fetch(getUrl(), {
      cache: "no-cache",
    });

    const data: {
      data: {
        slug: string;
      }[];
    } = await res.json();

    const sitemaps = data.data.map((blog) => {
      return {
        url: `${BaseUrl}/blogs/${blog.slug}`,
        lastModified: new Date().toISOString(),
        changefreq: "daily",
        priority: 0.8,
      };
    });

    return sitemaps;
  } catch (e) {
    return [];
  }
};

function getUrl() {
  return CMS_URL + "/items" + "/blogs" + "?fields=slug" + "&status=published";
}
