import { CMS_ASSETS_URL } from "@/config";
import { Blog } from "@/types";
import { formatDate, marginX } from "@/utils/constants";
import {
  Box,
  Flex,
  Grid,
  GridItem,
  Heading,
  Stack,
  Tag,
} from "@chakra-ui/react";
import Image from "next/image";
import React from "react";
import { FaUserCircle } from "react-icons/fa";
import RenderContent from "../common/render-content";
import RecentBlog from "./recent-blogs";

interface Props {
  blog: Blog;
}

const BlogDetail = ({ blog }: Props) => {
  const { title, content, date_created, thumbnail, slug } = blog;
  return (
    <Box marginX={marginX}>
      <Grid
        templateColumns={{ base: "1fr", md: "60% auto", lg: "75% auto" }}
        gap={10}
        py="3rem"
      >
        <GridItem>
          <Box>
            <Stack gap={4}>
              <Heading as="h1">{title}</Heading>

              <Stack w="fit-content">
                <Flex
                  gap={2}
                  align="center"
                  _hover={{
                    cursor: "pointer",
                  }}
                >
                  <FaUserCircle size={30} />
                  <Box
                    as="h4"
                    fontSize="xl"
                    fontWeight="semibold"
                    color="brand.main"
                  >
                    Artur & Helden
                  </Box>
                </Flex>

                <Tag w="fit-content" bg="brand.lightBlue" color="brand.white">
                  {formatDate(date_created)}
                </Tag>
              </Stack>

              <Box
                borderRadius="md"
                height="35rem"
                boxShadow="md"
                overflow="hidden"
                bg="main.200"
              >
                <Image
                  src={`${CMS_ASSETS_URL}/${thumbnail}`}
                  width={720}
                  className="thumbnail"
                  height={440}
                  style={{
                    objectFit: "contain",
                    width: "100%",
                    height: "100%",
                  }}
                  alt="blog thumbnail"
                />
              </Box>

              <RenderContent content={content || ""} />
            </Stack>
          </Box>
        </GridItem>
        <RecentBlog slug={slug} />
      </Grid>
    </Box>
  );
};

export default BlogDetail;
