import { CMS_ASSETS_URL, CMS_URL } from "@/config";
import { formatDate } from "@/utils/constants";
import { Box, GridItem, Heading, Stack, Tag } from "@chakra-ui/react";
import Image from "next/image";
import Link from "next/link";

interface RecentBlogType {
  slug: string;
  title: string;
  thumbnail: string;
  date_created: string;
}

function getUrl(slug: string) {
  return (
    CMS_URL +
    "/items" +
    "/blogs" +
    "?fields=" +
    "slug,title,thumbnail,date_created,excerpt" +
    "&sort=-date_created" +
    "&limit=3" +
    "&filter[slug][_neq]=" +
    slug +
    "&filter[status][_eq]=published"
  );
}

const RecentBlog = async ({ slug }: { slug: string }) => {
  const blogs = await getRecentBlogs(slug);

  if (!blogs) return null;

  return (
    <Box bg="brand.lightMain" p={3} borderRadius="md" h="fit-content">
      <GridItem>
        <Stack gap={8}>
          <Heading
            as="h3"
            color="brand.red"
            fontSize="2xl"
            fontWeight="semibold"
          >
            Recent Blogs
          </Heading>

          {blogs.map((item) => (
            <Stack
              key={item.slug}
              bg="brand.white"
              overflow="hidden"
              pb={3}
              borderRadius="xl"
              boxShadow="lg"
              gap={3}
              pos="relative"
            >
              <Stack h="150px">
                <Image
                  src={`${CMS_ASSETS_URL}/${item.thumbnail}`}
                  alt={item.title}
                  width={300}
                  height={150}
                  style={{
                    objectFit: "cover",
                    width: "100%",
                    height: "100%",
                  }}
                />
              </Stack>
              <Box flex={1} px={1}>
                <Link href={`/blogs/${item.slug}`}>
                  <Heading fontSize="md" fontWeight="semibold">
                    {item.title}
                  </Heading>
                </Link>
              </Box>
              <Box pos="absolute" top={0} right={0}>
                <Tag w="fit-content" bg="brand.main" color="brand.white">
                  {formatDate(item.date_created)}
                </Tag>
              </Box>
            </Stack>
          ))}
        </Stack>
      </GridItem>
    </Box>
  );
};

export default RecentBlog;

async function getRecentBlogs(slug: string) {
  try {
    const res = await fetch(getUrl(slug), {
      cache: "no-cache",
    });
    const data: { data: RecentBlogType[] } = await res.json();
    return data.data;
  } catch {
    return null;
  }
}
