import { CMS_ASSETS_URL } from "@/config";
import { Blog } from "@/types";

import { Box, Flex, Heading, Stack, Text } from "@chakra-ui/react";
import Image from "next/image";
import Link from "next/link";

interface Props {
  blog: Blog;
}

const BlogCard = ({
  blog: { slug, title, thumbnail, excerpt, date_created },
}: Props) => {
  const formattedDate = new Date(date_created);

  return (
    <Link href={`/blogs/${slug}`}>
      <Stack p={2} bg="brand.white" pos="relative" boxShadow="md">
        <Box height="16rem">
          <Image
            src={`${CMS_ASSETS_URL}/${thumbnail}`}
            alt={title}
            width={300}
            height={200}
            style={{
              width: "100%",
              height: "100%",
              objectFit: "cover",
            }}
          />
        </Box>
        <Heading
          as="h3"
          fontSize="lg"
          _hover={{
            textDecor: "underline",
            color: "blue.500", // 'brand.lightBlue
            cursor: "pointer",
          }}
        >
          {title}
        </Heading>
        <Text>
          {excerpt.slice(0, 100)}{" "}
          <Box as="span" fontWeight="bold" fontSize="lg" color="brand.main">
            ...
          </Box>
        </Text>
        <Flex
          gap={1}
          pos="absolute"
          top="20px"
          left="-10px"
          w="auto"
          height="auto"
          bg="brand.white"
          padding="3px 14px 5px 14px"
          border="1px solid lightBlue"
          align="center"
        >
          <Box as="span" fontSize="sm" color="brand.lightBlue">
            {formattedDate.toLocaleString("en-US", {
              month: "short",
              day: "numeric",
              year: "numeric",
            })}
          </Box>
        </Flex>
      </Stack>
    </Link>
  );
};

export default BlogCard;
