import { Box, Flex, Heading, Stack, Text } from "@chakra-ui/react";
import Link from "next/link";
import React from "react";
import { FaAngleRight } from "react-icons/fa";

interface Props {
  title: string;
  route: string;
  opacity?: string;
  image?: string;
  pos?: string;
}

const CommonHero = ({
  title,
  route,
  pos = "top",
  opacity = ".7",
  image = "/services/services-bg.png",
}: Props) => {
  return (
    <Stack
      minH={{ base: "40vh", sm: "55vh" }}
      align="center"
      justify="center"
      bgImage={image}
      bgSize="cover"
      bgPosition={pos}
      bgRepeat="no-repeat"
      position="relative"
      color="white"
      _before={{
        content: '""',
        position: "absolute",
        top: 0,
        left: 0,
        width: "100%",
        height: "100%",
        bg: `rgba(0,0,0,${opacity})`,
      }}
    >
      <Stack zIndex={999} maxW="xl">
        <Heading textAlign="center" fontSize={{ base: "2rem", md: "4rem" }}>
          {title}
        </Heading>
        <Flex align="center" justify="center" fontSize="18px" gap={2}>
          <Box fontWeight="bold" color="brand.main">
            <Link href="/">Home</Link>
          </Box>

          <FaAngleRight />
          <Text>{route}</Text>
        </Flex>
      </Stack>
    </Stack>
  );
};

export default CommonHero;
