import { marginX } from "@/utils/constants";
import { Heading, SimpleGrid, Stack, Text } from "@chakra-ui/react";
import Link from "next/link";
import React from "react";
import { ContactData } from ".";

const ContactCards = ({ data }: { data: ContactData[] }) => {
  return (
    <SimpleGrid
      columns={{ base: 1, sm: 2, lg: 4 }}
      marginX={marginX}
      my="4rem"
      gap={8}
    >
      {data.map((item, i) => (
        <Link key={i} href={item.href} target="_blank">
          <Stack
            boxShadow="lg"
            bg="brand.main"
            align="center"
            p="2rem"
            color="brand.white"
            borderRadius="lg"
            gap={5}
            transition="all .3s ease-in-out"
            _hover={{
              boxShadow: "xl",
              cursor: "pointer",
              transform: "translateY(-.9rem)",

              ".c-dot": {
                bg: "brand.lightBlue",
                color: "brand.white",
              },
              "#c-dot-icon": {
                color: "brand.white",
              },
            }}
          >
            <Heading fontSize="2xl">{item.title}:</Heading>
            <Stack
              p="1rem"
              w="fit-content"
              borderRadius="full"
              transition="all .3s ease-in-out"
              className="c-dot"
              bg="brand.white"
              color="brand.lightBlue"
            >
              <item.icon boxSize="2.5rem" />
            </Stack>

            <Text fontWeight="semibold" textAlign="center">
              {item.content}
            </Text>
          </Stack>
        </Link>
      ))}
    </SimpleGrid>
  );
};

export default ContactCards;
