import { ClockIcon, MailIcon, PhoneIcon } from "@/utils/icons";
import LocationIcon from "@/utils/icons/LocationIcon";
import { ChakraProps } from "@chakra-ui/react";
import React from "react";
import Map from "../common/map";
import ContactCards from "./contact-cards";
import ContactForm from "./contact-form";
import { CMS_URL } from "@/config";
import { ContactPage } from "@/types";

export type ContactData = {
  icon: React.FC<ChakraProps>;
  title: string;
  content: string;
  href: string;
};

const ContactContent = async () => {
  const data = await getContactData();
  return (
    <>
      <ContactCards
        data={getContactCardsWithIcons(
          data.address,
          data.working_hours,
          data.our_email,
          data.give_us_a_call_number
        )}
      />
      <ContactForm
        title={data.form_title}
        imageId={data.form_image}
        description={data.form_description}
      />

      <Map />
    </>
  );
};

export default ContactContent;

async function getContactData() {
  try {
    const res = await fetch(`${CMS_URL}/items/contact`, {
      cache: "no-cache",
    });
    const data: {
      data: ContactPage;
    } = await res.json();

    return data.data;
  } catch (error) {
    return {
      id: 1,
      user_created: "88b78413-74b7-4ffd-83ef-8e150788d564",
      date_created: "2024-03-25T07:53:01.804Z",
      user_updated: null,
      date_updated: null,
      address: "Carl-Klein-Straße 6, 42897 Remscheid, Germany",
      working_hours: "Montag - Freitag: 8:00 - 17:00 Uhr",
      our_email: "info@arturundhelden.de",
      give_us_a_call_number: "+49 172 2762328",
      form_image: "32b7d9a6-534f-42f8-bd73-a9f9b8c8abac",
      form_title: "In Kontakt kommen!",
      form_description:
        "Ihre E-Mails werden innerhalb von 24 Stunden beantwortet – in der Regel jedoch schneller!",
    };
  }
}

function getContactCardsWithIcons(
  address: string,
  working_hrs: string,
  email: string,
  phone: string
): ContactData[] {
  return [
    {
      icon: LocationIcon,
      title: "Adresse",
      content: address,
      href: "https://maps.app.goo.gl/5yS11A1j5WWFQC9J6",
    },
    {
      icon: ClockIcon,
      title: "Arbeitszeit",
      content: working_hrs,
      href: "https://maps.app.goo.gl/5yS11A1j5WWFQC9J6",
    },
    {
      icon: MailIcon,
      title: "Unsere E-Mail",
      content: email,
      href: "mailto:info@arturundhelden.de",
    },
    {
      icon: PhoneIcon,
      title: "Rufen Sie uns an",
      content: phone,
      href: "tel:+491722762328",
    },
  ];
}
