import { CMS_ASSETS_URL } from "@/config";
import { HowItWorksCard } from "@/types";
import { marginX } from "@/utils/constants";
import {
  Box,
  Button,
  Flex,
  Heading,
  SimpleGrid,
  Stack,
  Text,
} from "@chakra-ui/react";
import Image from "next/image";
import Link from "next/link";
import React from "react";

interface Props {
  title: string;
  cards: HowItWorksCard[];
}

const HowItWorks = ({ title, cards }: Props) => {
  return (
    <Stack marginX={marginX} my="4rem" gap={4}>
      <Button
        alignSelf={{ base: "center", sm: "initial" }}
        bg="brand.main"
        w="fit-content"
        py="1.6rem"
        px="2rem"
        borderRadius="none"
        transform="matrix(1, 0, -0.26, 0.97, 0, 0)"
        fontSize="2xl"
      >
        {title}
      </Button>

      <SimpleGrid columns={{ base: 1, sm: 2, md: 4 }} gap={8}>
        {cards.map((data, i) => (
          <Stack key={i} gap={3} align={{ base: "center", sm: "normal" }}>
            <Image
              src={`${CMS_ASSETS_URL}/${data.image}`}
              width={100}
              height={100}
              alt={data.title}
            />
            <Flex gap={1}>
              <Box as="p" bg="brand.main" p=".2rem">
                {i + 1}
              </Box>
              {data.link ? (
                <Link href={data.link} target="_blank">
                  <Heading
                    as="h3"
                    fontSize="xl"
                    _hover={{
                      color: "blue.500",
                      textDecoration: "underline",
                    }}
                    cursor="pointer"
                  >
                    {data.title}
                  </Heading>
                </Link>
              ) : (
                <Heading as="h3" fontSize="xl">
                  {data.title}
                </Heading>
              )}
            </Flex>
            <Text textAlign={{ base: "center", sm: "initial" }}>
              {data.description}
            </Text>
          </Stack>
        ))}
      </SimpleGrid>
    </Stack>
  );
};

export default HowItWorks;
