import { CMS_ASSETS_URL } from "@/config";
import { Service } from "@/types";
import { marginX } from "@/utils/constants";
import {
  Box,
  Button,
  Heading,
  SimpleGrid,
  Stack,
  Text,
} from "@chakra-ui/react";
import Image from "next/image";
import Link from "next/link";
import React from "react";

interface Props {
  title: string;
  services: Service[];
}

const OurServices = ({ title, services }: Props) => {
  return (
    <Box bg="brand.darkBlue" color="brand.white" my="4rem" py="6rem">
      <Stack marginX={marginX}>
        <Button
          bg="brand.main"
          w="fit-content"
          mx={{ base: "auto", sm: 0 }}
          py="1.6rem"
          px="2rem"
          borderRadius="none"
          transform="matrix(1, 0, -0.26, 0.97, 0, 0)"
          fontSize="2xl"
        >
          {title}
        </Button>
        <SimpleGrid columns={{ base: 1, md: 3 }} gap={10} mt="3rem">
          {services.map((service, i) => (
            <Link key={i} href={`/leistungen#${service.slug}`}>
              <Stack
                border="1px solid var(--chakra-colors-brand-main)"
                p={4}
                align={{ base: "center", sm: "normal" }}
                transition="all .3s ease-in-out"
                _hover={{
                  color: "brand.lightBlue",
                  bg: "brand.main",
                  cursor: "pointer",
                }}
              >
                <Image
                  src={`${CMS_ASSETS_URL}/${service.image_icon}`}
                  alt={service.title}
                  width={70}
                  height={70}
                />
                <Heading as="h3" fontSize="lg">
                  {service.title}
                </Heading>
                <Text
                  fontSize="sm"
                  textAlign={{ base: "center", sm: "initial" }}
                >
                  {service.excerpt.slice(0, 250)}
                </Text>
              </Stack>
            </Link>
          ))}
        </SimpleGrid>
      </Stack>
    </Box>
  );
};

export default OurServices;
