import { CMS_ASSETS_URL } from "@/config";
import { Stat } from "@/types";
import { marginX } from "@/utils/constants";
import { Box, Button, Heading, SimpleGrid, Stack } from "@chakra-ui/react";
import Image from "next/image";
import React from "react";
import { AnimatedCounter } from "../common/animated-counter";
import Link from "next/link";

interface Props {
  stats: Stat[];
}

const Stats = ({ stats }: Props) => {
  return (
    <Stack marginX={marginX} my="6rem" gap="4rem">
      <SimpleGrid columns={{ base: 1, md: 3 }} gap={10} alignItems="center">
        {stats.map((stat, i) => (
          <Stack key={i} align="center" height="100%" gap={3}>
            <Box>
              <Image
                src={`${CMS_ASSETS_URL}/${stat.image}`}
                alt={stat.title}
                style={{
                  height: "100%",
                  width: "100%",
                  objectFit: "contain",
                }}
                width={250}
                height={250}
              />
            </Box>
            <Stack align="center" mt="auto">
              <Heading
                as="p"
                fontFamily="monospace"
                fontSize="5xl"
                color="brand.main"
              >
                <AnimatedCounter from={0} to={parseInt(stat.stat)} />+
              </Heading>
              <Heading as="h3">{stat.title}</Heading>
            </Stack>
          </Stack>
        ))}
      </SimpleGrid>
      <Link
        href="/umzugsgutliste"
        target="_blank"
        style={{
          alignSelf: "center",
        }}
      >
        <Button
          bg="brand.main"
          w="fit-content"
          _hover={{
            bg: "brand.lightBlue",
            color: "brand.white",
          }}
        >
          JETZ BUCHEN
        </Button>
      </Link>
    </Stack>
  );
};

export default Stats;
