import { CMS_ASSETS_URL } from "@/config";
import { WeAreArturImages } from "@/types";
import { marginX } from "@/utils/constants";
import { Grid, GridItem, Heading, Text } from "@chakra-ui/react";
import Image from "next/image";
import RenderContent from "../common/render-content";

interface Props {
  images: WeAreArturImages[];
  title: string;
  subTitle: string;
  description: string;
}

const WeAreAtur = ({ images, title, subTitle, description }: Props) => {
  return (
    <Grid
      my={{ base: "4rem", sm: "6rem", md: "8rem" }}
      marginX={marginX}
      gap={6}
      gridTemplateColumns={{ base: "1fr", sm: "repeat(4,1fr)" }}
      gridTemplateRows={{ base: "auto", lg: "repeat(2,1fr)" }}
    >
      <GridItem
        rowSpan={{ base: 1, lg: 2 }}
        colSpan={{ base: 1, sm: 2, lg: 1 }}
        height={{ base: "30rem", lg: "auto" }}
      >
        <Image
          src={`${CMS_ASSETS_URL}/${images[0].directus_files_id}`}
          style={{
            width: "100%",
            height: "100%",
            objectFit: "cover",
          }}
          width={500}
          height={500}
          alt="img1"
        />
      </GridItem>
      <GridItem
        overflow="hidden"
        borderTopLeftRadius={{ base: "0", lg: "80px" }}
        colSpan={{ base: "auto", sm: 2, lg: 1 }}
      >
        <Image
          style={{
            width: "100%",
            height: "100%",
            objectFit: "cover",
          }}
          src={`${CMS_ASSETS_URL}/${images[1].directus_files_id}`}
          width={500}
          height={500}
          alt="img1"
        />
      </GridItem>
      <GridItem
        overflow="hidden"
        borderBottomLeftRadius={{ base: "0", lg: "80px" }}
        colSpan={{ base: "auto", sm: 2, lg: 1 }}
      >
        <Image
          style={{
            width: "100%",
            height: "100%",
            objectFit: "cover",
          }}
          src={`${CMS_ASSETS_URL}/${images[2].directus_files_id}`}
          width={500}
          height={500}
          alt="img1"
        />
      </GridItem>
      <GridItem
        gridColumn={{ base: "1/2", sm: "1/3", lg: "3/5" }}
        gridRow="1/3"
        rowSpan={{ base: "auto", lg: 2 }}
        display="flex"
        flexDir="column"
        gap={2}
      >
        <Heading as="h3" fontSize="lg" color="brand.main" fontWeight={600}>
          {subTitle}
        </Heading>
        <Heading>{title}</Heading>
        <RenderContent content={description} />
      </GridItem>
    </Grid>
  );
};

export default WeAreAtur;
