"use client";
import { navItems } from "@/utils/constants";
import {
  Box,
  Drawer,
  DrawerBody,
  DrawerCloseButton,
  DrawerContent,
  DrawerHeader,
  DrawerOverlay,
  IconButton,
  Stack,
  Text,
  useDisclosure,
} from "@chakra-ui/react";
import Link from "next/link";
import { RxHamburgerMenu } from "react-icons/rx";
import AngebotButton from "./angebot-button";

const MobileNav = () => {
  const { isOpen, onOpen, onClose } = useDisclosure();

  return (
    <Box>
      <IconButton
        aria-label="Menü öffnen"
        as={RxHamburgerMenu}
        onClick={onOpen}
        boxSize={8}
        color="brand.black"
        bg="none"
        _hover={{ background: "none" }}
      />
      <Drawer isOpen={isOpen} placement="right" onClose={onClose}>
        <DrawerOverlay />
        <DrawerContent bg="brand.main">
          <DrawerCloseButton
            color="brand.black"
            w="48px"
            h="48px"
            _focus={{
              color: "brand.white",
              boxShadow: "none",
              border: "none",
              outline: "none",
            }}
          />
          <DrawerHeader></DrawerHeader>

          <DrawerBody mt={5}>
            <Stack
              direction="column"
              align="flex-start"
              fontFamily="Poppins san-serif"
              fontWeight="300"
              lineHeight="44px"
              fontSize="20px"
              color="brand.lightBlue"
              gap={4}
            >
              {navItems.map((item, i) => (
                <Link key={item.name} href={item.link}>
                  <Text
                    fontSize="xl"
                    key={i}
                    color="brand.green"
                    fontWeight="semibold"
                    _hover={{
                      color: "brand.main",
                      cursor: "pointer",
                    }}
                    onClick={() => {
                      onClose();
                    }}
                  >
                    {item.name}
                  </Text>
                </Link>
              ))}

              <AngebotButton
                onClose={onClose}
                bg="brand.black"
                color="brand.white"
              />
            </Stack>
          </DrawerBody>
        </DrawerContent>
      </Drawer>
    </Box>
  );
};

export default MobileNav;
