import { SocialsAndContacts } from "@/types";
import { marginX } from "@/utils/constants";
import {
  FacebookIcon,
  InstagramIcon,
  MailIcon,
  PhoneIcon,
} from "@/utils/icons";
import { Box, Flex, Stack, Text } from "@chakra-ui/react";
import Link from "next/link";

interface Props {
  data: SocialsAndContacts;
}

const TopNav = ({ data }: Props) => {
  return (
    <Box bg="brand.darkBlue" py=".7rem" color="brand.white">
      <Flex
        justify="space-between"
        align="center"
        flexDir={{ base: "column", sm: "row" }}
        marginX={marginX}
        gap={{ base: 2, sm: 0 }}
        paddingBottom=".2rem"
      >
        <Flex gap={4}>
          {getLeftContact(data).map((contact, i) => (
            <Link key={i} href={contact.link}>
              <Flex key={i} gap={1} align="center">
                <Box as={contact.icon} color="brand.main" />
                <Text
                  fontWeight="500"
                  _hover={{
                    color: "brand.main",
                  }}
                >
                  {contact.text}
                </Text>
              </Flex>
            </Link>
          ))}
        </Flex>
        <Flex gap={2} order={{ base: -1, sm: 1 }}>
          {getSocials(data).map((social, i) => (
            <Link key={i} href={social.link} target="_blank">
              <Stack
                bg={social.color}
                _hover={{
                  bg: "brand.main",
                }}
                borderRadius="full"
                p={1}
              >
                <Box
                  key={i}
                  transition="all .2s ease-in-out"
                  as={social.icon}
                  boxSize={4}
                />
              </Stack>
            </Link>
          ))}
        </Flex>
      </Flex>
    </Box>
  );
};

export default TopNav;

function getLeftContact(data: SocialsAndContacts) {
  return [
    {
      icon: PhoneIcon,
      link: "tel:" + data.tel,
      text: data.tel,
    },
    {
      icon: MailIcon,
      link: "mailto:" + data.email,
      text: data.email,
    },
  ];
}

function getSocials(data: SocialsAndContacts) {
  return [
    {
      icon: FacebookIcon,
      link: data.facebook,
      color: "#1877F2",
    },
    {
      icon: InstagramIcon,
      link: data.instagram,
      color: "#c1558b",
    },
  ];
}
