import { marginX } from "@/utils/constants";
import { Heading, SimpleGrid, Stack } from "@chakra-ui/react";
import RenderContent from "@/components/common/render-content";
import Image from "next/image";
import { Service } from "@/types";
import { CMS_ASSETS_URL } from "@/config";

interface Props {
  servicesData: Service[];
}

const Services = ({ servicesData }: Props) => {
  return (
    <Stack
      marginX={marginX}
      my="4rem"
      gap={{ base: "2rem", sm: "4rem", md: "6rem" }}
    >
      {servicesData.map((s, i) => (
        <SimpleGrid key={i} columns={{ base: 1, md: 2 }} gap={8} id={s.slug}>
          <Stack order={{ base: 1, sm: i % 2 === 0 ? 0 : 1 }}>
            <Heading as="h3" fontSize="lg">
              {s.title}
            </Heading>
            <RenderContent content={s.content || ""} />
          </Stack>
          <Stack overflow="hidden" borderRadius="lg">
            <Image
              src={`${CMS_ASSETS_URL}/${s.thumbnail}`}
              alt={s.title}
              width={500}
              height={500}
              style={{ width: "100%", height: "100%", objectFit: "cover" }}
            />
          </Stack>
        </SimpleGrid>
      ))}
    </Stack>
  );
};

export default Services;
