"use client";
import { marginX } from "@/utils/constants";
import { Box, Flex, Heading, Stack, Text } from "@chakra-ui/react";
import Image from "next/image";
import { Splide, SplideSlide } from "@splidejs/react-splide";
// Default theme
import "@splidejs/react-splide/css";
import { Testimonial } from "@/types";
import { CMS_ASSETS_URL } from "@/config";

interface Props {
  title: string;
  testimonials: Testimonial[];
}

const Testimonials = ({ title, testimonials }: Props) => {
  return (
    <Stack my="4rem" gap="2rem" marginX={marginX} align="center">
      <Heading textAlign="center" fontSize="3xl">
        {title}
      </Heading>
      <Box overflow="hidden" pos="relative" w="100%">
        <Splide
          options={{
            rewind: true,

            type: "loop",
            autoplay: true,
          }}
          aria-label="Testimonials slider"
        >
          {testimonials.map((t, i) => (
            <SplideSlide key={i}>
              <Flex
                justify="center"
                align="center"
                gap={2}
                flexDir={{ base: "column", sm: "row" }}
              >
                <Box>
                  <Image
                    src={`${CMS_ASSETS_URL}/${t.author_image}`}
                    alt={t.author_name}
                    width={100}
                    height={100}
                    style={{
                      borderRadius: "50%",
                    }}
                  />
                </Box>
                <Stack maxW="lg" textAlign={{ base: "center", sm: "left" }}>
                  <Text fontSize="lg">{t.content}</Text>
                  <Stack gap={1}>
                    <Heading as="h4" fontSize="xl" fontWeight={600}>
                      {t.author_name}
                    </Heading>
                    <Text color="GrayText">{t.author_position}</Text>
                  </Stack>
                </Stack>
              </Flex>
            </SplideSlide>
          ))}
        </Splide>
      </Box>
    </Stack>
  );
};

export default Testimonials;
