import { create } from "zustand";
import {
  defaultArbeitszimmerData,
  defaultDieleData,
  defaultEsszimmerData,
  defaultGarageData,
  defaultKellerData,
  defaultKinderzimmerData,
  defaultKucheData,
  defaultSchlafzimmerData,
  defaultWohnzimmerData,
} from "./default";

export type Field = {
  id: number;
  pk: string;
  number: number;
  RE: number;
  gesRE: number;
  gegenstand: string;
  fpKey: string;
};

export interface CustomItem {
  fields: Field[];
  sonstiges: string;
}

export interface FieldItem {
  wohnzimmer: CustomItem;
  arbeitszimmer: CustomItem;
  kinderzimmer: CustomItem;
  diele: CustomItem;
  esszimmer: CustomItem;
  schlafzimmer: CustomItem;
  kuche: CustomItem;
  keller: CustomItem;
  garage: CustomItem;
}

interface MoveRequest extends FieldItem {
  total: number;
  modify: (id: number, value: number, type: keyof FieldItem) => void;
  setSonstiges: (value: string, type: keyof FieldItem) => void;
  resetStore: () => void;
}

const useMoveRequestStore = create<MoveRequest>((set) => ({
  wohnzimmer: defaultWohnzimmerData,
  arbeitszimmer: defaultArbeitszimmerData,
  kinderzimmer: defaultKinderzimmerData,
  diele: defaultDieleData,
  esszimmer: defaultEsszimmerData,
  schlafzimmer: defaultSchlafzimmerData,
  kuche: defaultKucheData,
  keller: defaultKellerData,
  garage: defaultGarageData,

  total: 0,
  modify: (id, value, type) =>
    set((store) => {
      if (!type) return store;
      return {
        ...store,
        [type]: {
          ...store[type],
          fields: store[type].fields.map((field) => {
            if (field.id === id) {
              return {
                ...field,
                number: value,
                gesRE: field.RE * value,
              };
            }
            return field;
          }),
        },
      };
    }),
  setSonstiges: (value, type) => {
    set((store) => {
      if (!type) return store;

      return {
        ...store,
        [type]: {
          ...store[type],
          sonstiges: value,
        },
      };
    });
  },
  resetStore() {
    set(() => ({
      wohnzimmer: defaultWohnzimmerData,
      arbeitszimmer: defaultArbeitszimmerData,
      kinderzimmer: defaultKinderzimmerData,
      diele: defaultDieleData,
      esszimmer: defaultEsszimmerData,
      schlafzimmer: defaultSchlafzimmerData,
      kuche: defaultKucheData,
      keller: defaultKellerData,
      garage: defaultGarageData,
      total: 0,
    }));
  },
}));

export default useMoveRequestStore;
