/*

import { create } from "zustand";
import { produce } from "immer";

type Field = {
  id: string;
  number: number;
  RE: number;
  gesRE: number;
  gegenstand: string;
};

interface Common {
  sofaCouchLiegeJeSitz: Field;
  sitzlandschaftElementJeSitz: Field;
  sesselMitArmlehnen: Field;
  sesselOhneArmlehnen: Field;
  stuhl: Field;
  stuhlMitArmlehnen: Field;
  tischBis06M: Field;
  tischBis10M: Field;
  tischBis12M: Field;
  tischuber12M: Field;
  wohnzSchrankZerlegbJeAngefM: Field;
  anbauwandB38CmTiefeJeAngefM: Field;
  anbauwandU38CmTiefeJeAngefM: Field;
  bucherregalZerlegbarJaAngefM: Field;
  buffetMitAufsatz: Field;
  standuhr: Field;
  schreibtischBis16M: Field;
  schreibtischUber16M: Field;
  sekretar: Field;
  sideboard: Field;
  musikschrank: Field;
  stereoanlage: Field;
  fernseher: Field;
  videogerat: Field;
  fernsehtischSchrankchen: Field;
  klavier: Field;
  flugel: Field;
  heimorgel: Field;
  nahmaschineSchrank: Field;
  stehlampe: Field;
  bilderUber08M: Field;
  deckenlampe: Field;
  luster: Field;
  teppich: Field;
  brucke: Field;
  pflanzenBis15M: Field;
  pflanzenUber15M: Field;
}

interface Wohnzimmer {
  total: number;
  modify: (field: keyof Common, value: number) => void;
}

const useMoveRequestStore = create<Wohnzimmer>((set) => ({
  sofaCouchLiegeJeSitz: {
    number: 0,
    RE: 8,
    gesRE: 0,
    gegenstand: "Sofa, Couch, Liege je Sitz",
  },
  sitzlandschaftElementJeSitz: {
    number: 0,
    RE: 8,
    gesRE: 0,
    gegenstand: "Sitzlandschaft Element je Sitz",
  },
  sesselMitArmlehnen: {
    number: 0,
    RE: 4,
    gesRE: 0,
    gegenstand: "Sessel mit Armlehnen",
  },
  sesselOhneArmlehnen: {
    number: 0,
    RE: 3,
    gesRE: 0,
    gegenstand: "Sessel ohne Armlehnen",
  },
  stuhl: { number: 0, RE: 2, gesRE: 0, gegenstand: "Stuhl" },
  stuhlMitArmlehnen: {
    number: 0,
    RE: 3,
    gesRE: 0,
    gegenstand: "Stuhl mit Armlehnen",
  },
  tischBis06M: { number: 0, RE: 4, gesRE: 0, gegenstand: "Tisch bis 0.6m" },
  tischBis10M: { number: 0, RE: 6, gesRE: 0, gegenstand: "Tisch bis 1.0m" },
  tischBis12M: { number: 0, RE: 8, gesRE: 0, gegenstand: "Tisch bis 1.2m" },
  tischuber12M: { number: 0, RE: 10, gesRE: 0, gegenstand: "Tisch über 1.2m" },
  wohnzSchrankZerlegbJeAngefM: {
    number: 0,
    RE: 10,
    gesRE: 0,
    gegenstand: "Wohnz. Schrank zerlegb. je angef. m",
  },
  anbauwandB38CmTiefeJeAngefM: {
    number: 0,
    RE: 10,
    gesRE: 0,
    gegenstand: "Anbauwand b. 38cm Tiefe je angef. m",
  },
  anbauwandU38CmTiefeJeAngefM: {
    number: 0,
    RE: 12,
    gesRE: 0,
    gegenstand: "Anbauwand ü. 38cm Tiefe je angef. m",
  },
  bucherregalZerlegbarJaAngefM: {
    number: 0,
    RE: 6,
    gesRE: 0,
    gegenstand: "Bücherregal zerlegbar je angef. m",
  },
  buffetMitAufsatz: {
    number: 0,
    RE: 10,
    gesRE: 0,
    gegenstand: "Buffet mit Aufsatz",
  },
  standuhr: { number: 0, RE: 8, gesRE: 0, gegenstand: "Standuhr" },
  schreibtischBis16M: {
    number: 0,
    RE: 8,
    gesRE: 0,
    gegenstand: "Schreibtisch bis 1.6m",
  },
  schreibtischUber16M: {
    number: 0,
    RE: 10,
    gesRE: 0,
    gegenstand: "Schreibtisch über 1.6m",
  },
  sekretar: { number: 0, RE: 8, gesRE: 0, gegenstand: "Sekretär" },
  sideboard: { number: 0, RE: 8, gesRE: 0, gegenstand: "Sideboard" },
  musikschrank: { number: 0, RE: 8, gesRE: 0, gegenstand: "Musikschrank" },
  stereoanlage: { number: 0, RE: 4, gesRE: 0, gegenstand: "Stereoanlage" },
  fernseher: { number: 0, RE: 4, gesRE: 0, gegenstand: "Fernseher" },
  videogerat: { number: 0, RE: 4, gesRE: 0, gegenstand: "Videogerät" },
  fernsehtischSchrankchen: {
    number: 0,
    RE: 4,
    gesRE: 0,
    gegenstand: "Fernsehtisch, Schränkchen",
  },
  klavier: { number: 0, RE: 20, gesRE: 0, gegenstand: "Klavier" },
  flugel: { number: 0, RE: 30, gesRE: 0, gegenstand: "Flügel" },
  heimorgel: { number: 0, RE: 10, gesRE: 0, gegenstand: "Heimorgel" },
  nahmaschineSchrank: {
    number: 0,
    RE: 4,
    gesRE: 0,
    gegenstand: "Nähmaschine, Schrank",
  },
  stehlampe: { number: 0, RE: 2, gesRE: 0, gegenstand: "Stehlampe" },
  bilderUber08M: { number: 0, RE: 2, gesRE: 0, gegenstand: "Bilder über 0.8m" },
  deckenlampe: { number: 0, RE: 2, gesRE: 0, gegenstand: "Deckenlampe" },
  luster: { number: 0, RE: 4, gesRE: 0, gegenstand: "Lüster" },
  teppich: { number: 0, RE: 2, gesRE: 0, gegenstand: "Teppich" },
  brucke: { number: 0, RE: 4, gesRE: 0, gegenstand: "Brücke" },
  pflanzenBis15M: {
    number: 0,
    RE: 2,
    gesRE: 0,
    gegenstand: "Pflanzen bis 1.5m",
  },
  pflanzenÜber15M: {
    number: 0,
    RE: 4,
    gesRE: 0,
    gegenstand: "Pflanzen über 1.5m",
  },
  total: 0,
  modify: (field, value) =>
    set(
      produce((state: Wohnzimmer) => {
        state[field].number = value;
        state[field].gesRE = value * state[field].RE;
        state.total = Object.values(state).reduce(
          (acc, field) => acc + field.gesRE,
          0
        );

        return state;
      })
    ),
}));

export default useMoveRequestStore;
*/
